@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-30 09:22:51
-@LastEditTime: 2021-09-06 10:00:51
+@LastEditTime: 2021-09-06 15:12:16
 @LastEditors: HuangJianYi
 @Description: 排队系统帮助类
 """
@@ -13,7 +13,7 @@ from seven_cloudapp_frame.libs.customize.seven_helper import *
 
 class QueueUpHelper:
     """
-    :description: 排队系统帮助类 提供加入排队、退出排队、查询单个排队情况、批量查询排队情况、更新可操作时间、签到、清空队列等功能
+    :description: 排队系统帮助类 提供加入排队、退出排队、查询单个排队情况、批量查询排队情况、更新可操作时间、签到等功能
     """
     logger_error = Logger.get_logger_by_name("log_error")
 
@@ -180,44 +180,6 @@ class QueueUpHelper:
         if invoke_result_data.error_code == "del":
             self._delete_user(app_id,queue_name)
 
-    @classmethod
-    def clear(self, app_id, queue_name):
-        """
-        :description: 清空排队
-        :param app_id：应用标识
-        :param queue_name：队列名称
-        :return: 
-        :last_editors: HuangJianYi
-        """
-        invoke_result_data = InvokeResultData()
-        try:
-            redis_init = SevenHelper.redis_init()
-            zset_name = self._get_zset_name(app_id,queue_name)
-            hash_name = self._get_user_hash_name(app_id)
-            zset_result = redis_init.delete(zset_name)
-            hash_result = 1
-            match_result = redis_init.hscan_iter(hash_name, match=f'*_queuename_{queue_name}')
-            queue_name_list = []
-            for item in match_result:
-                queue_name_list.append(item[0])
-            if len(queue_name_list) > 0:
-                hash_del_keys = tuple(queue_name_list)
-                hash_result = redis_init.hdel(hash_name, *hash_del_keys)
-
-            if zset_result > 0 and hash_result > 0:
-                return invoke_result_data
-            else:
-                invoke_result_data.success = False
-                invoke_result_data.error_code = "error"
-                invoke_result_data.error_message = "无排队数据"
-                return invoke_result_data
-        except Exception as ex:
-            self.logger_error.error("【清空排队】" + str(ex))
-            invoke_result_data.success = False
-            invoke_result_data.error_code = "error"
-            invoke_result_data.error_message = "无排队数据"
-            return invoke_result_data
-
     @classmethod
     def queue(self, app_id, queue_name, user_id, user_nick="", queue_length=10, all_queue_limit_num=500):
         """
@@ -244,25 +206,26 @@ class QueueUpHelper:
             if all_queue_limit_num > 0 and self._get_all_queue_num(app_id) >= all_queue_limit_num:
                 SevenHelper.redis_release_lock(acquire_lock_name, identifier)
                 invoke_result_data.success = False
-                invoke_result_data.error_code = "error"
-                invoke_result_data.error_message = "排队失败,超过排队人数上限"
+                invoke_result_data.error_code = "total_limit"
+                invoke_result_data.error_message = "排队失败,排队总人数已达上限"
                 return invoke_result_data
             zset_name = self._get_zset_name(app_id,queue_name)
             data = str(user_id)
+            expire_time = 7 * 24 * 3600
             if not redis_init.zscore(zset_name, data):
                 if self._get_queue_num(app_id,queue_name) >= queue_length:
                     SevenHelper.redis_release_lock(acquire_lock_name, identifier)
                     invoke_result_data.success = False
-                    invoke_result_data.error_code = "limit"
-                    invoke_result_data.error_message = "当前排队人数已达上限"
+                    invoke_result_data.error_code = "queue_limit"
+                    invoke_result_data.error_message = "排队失败,当前排队人数已达上限"
                     return invoke_result_data
                 queue_no = self._get_queue_no(app_id,queue_name)
                 redis_init.zadd(zset_name, {data: queue_no})
-                redis_init.expire(zset_name, 7 * 24 * 3600)
+                redis_init.expire(zset_name, expire_time)
 
                 user_zset_name = self._get_user_zset_name(app_id)
                 redis_init.zincrby(user_zset_name, 1, data)
-                redis_init.expire(user_zset_name, 7 * 24 * 3600)
+                redis_init.expire(user_zset_name, expire_time)
 
                 hash_value = {}
                 hash_value["queue_name"] = queue_name  #排队名称
@@ -287,7 +250,7 @@ class QueueUpHelper:
                 hash_name = self._get_user_hash_name(app_id)
                 hash_key = f"userid_{data}_queuename_{queue_name}"
                 redis_init.hsetnx(hash_name, hash_key, SevenHelper.json_dumps(hash_value))
-                redis_init.expire(hash_name, 7 * 24 * 3600)
+                redis_init.expire(hash_name, expire_time)
 
                 result_data = {}
                 result_data["queue_no"] = hash_value["queue_no"]  #排队号
@@ -324,6 +287,11 @@ class QueueUpHelper:
         """
         invoke_result_data = InvokeResultData()
         try:
+            if SevenHelper.is_continue_request(f"queueup_pop:{queue_name}_{user_id}",expire=1*1000) == True:
+                invoke_result_data.success = False
+                invoke_result_data.error_code = "error"
+                invoke_result_data.error_message = "对不起,请1秒后再试"
+                return invoke_result_data
             zset_name = self._get_zset_name(app_id,queue_name)
             data = str(user_id)
             redis_init = SevenHelper.redis_init()
@@ -401,7 +369,7 @@ class QueueUpHelper:
     @classmethod
     def muti_user_query(self, app_id, user_id):
         """
-        :description: 批量查询某用户排队情况
+        :description: 批量查询某用户排队情况 只包含已排队的信息
         :param app_id：应用标识
         :param user_id：用户标识
         :return: 
@@ -430,7 +398,7 @@ class QueueUpHelper:
     @classmethod
     def muti_queue_query(self, app_id, queue_name_list, user_id):
         """
-        :description: 批量查询排队情况
+        :description: 批量查询排队情况 包含已排队和未排队的信息
         :param app_id：应用标识
         :param queue_name_list：查询队列集合
         :param user_id：用户标识
