@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-05-12 20:11:48
-@LastEditTime: 2021-09-02 18:50:00
+@LastEditTime: 2021-09-03 17:40:35
 @LastEditors: HuangJianYi
 :description: 
 """
@@ -69,7 +69,7 @@ class AssetBaseModel():
                 redis_init.expire(hash_name_1, 24 * 3600)
             
             hash_name_2 = f"{hash_name_1}:{hash_key_1}"
-            redis_init.hincrby(hash_name_2, {str(SevenHelper.get_now_int(fmt='%Y%m%d%H%M'))}, 1)
+            redis_init.hincrby(hash_name_2, str(SevenHelper.get_now_int(fmt='%Y%m%d%H%M')), 1)
             redis_init.expire(hash_name_2, 24 * 3600)
             
     def update_user_asset(self, app_id, act_id, module_id, user_id, open_id, user_nick, asset_type, asset_value, asset_object_id, source_type, source_object_id, source_object_name, log_title, only_id="",handler_name="",request_code="", info_json={}):
@@ -271,11 +271,12 @@ class AssetBaseModel():
             invoke_result_data.data = user_asset.asset_value
 
         except Exception as ex:
-            db_transaction.rollback_transaction()
             if self.context:
                 self.context.logging_link_error("【变更资产】" + str(ex))
             elif self.logging_link_error:
                 self.logging_link_error("【变更资产】" + str(ex))
+            if db_transaction.is_transaction == True:
+                db_transaction.rollback_transaction()
             invoke_result_data.success = False
             invoke_result_data.error_code = "exception"
             invoke_result_data.error_message = "系统繁忙,请稍后再试"
@@ -316,7 +317,7 @@ class AssetBaseModel():
             for user_asset_dict in user_asset_dict_list:
                 if user_asset_dict["app_id"] != str(app_id):
                     user_asset_dict["asset_value"] = 0
-                if self._get_asset_check_code(user_asset_dict["id"], user_asset_dict["asset_value"], app_id) != user_asset_dict["asset_check_code"]:
+                if self._get_asset_check_code(user_asset_dict["id_md5"], user_asset_dict["asset_value"], app_id) != user_asset_dict["asset_check_code"]:
                     user_asset_dict["asset_value"] = 0
         return user_asset_dict_list
 
@@ -340,7 +341,7 @@ class AssetBaseModel():
         if user_asset_dict:
             if user_asset_dict["app_id"] != str(app_id):
                 user_asset_dict["asset_value"] = 0
-            if self._get_asset_check_code(user_asset_dict["id"], user_asset_dict["asset_value"], app_id) != user_asset_dict["asset_check_code"]:
+            if self._get_asset_check_code(user_asset_dict["id_md5"], user_asset_dict["asset_value"], app_id) != user_asset_dict["asset_check_code"]:
                 user_asset_dict["asset_value"] = 0
         return user_asset_dict
 
