@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 09:24:43
-@LastEditTime: 2021-09-03 18:00:26
+@LastEditTime: 2021-09-06 14:10:38
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -610,24 +610,27 @@ class OrderBaseModel(FrameBaseModel):
                     if len(tao_pay_order_list) > 0:
                         result = TaoPayOrderModel(context=self.context).add_list(tao_pay_order_list)
                         if result == True and buy_num > 0: 
-       
-                            only_id =  f"sync_tao_pay_order_{handler_name}_{request_code}" if handler_name and request_code else ""
                             asset_base_model = AssetBaseModel(context=self.context)
-                            asset_invoke_result_data = asset_base_model.update_user_asset(app_id,act_id,module_id,user_id,user_info_dict["open_id"],user_info_dict["user_nick"],asset_type,buy_num,asset_object_id,1,"购买","",only_id,handler_name,request_code,info_json={})
-                            if asset_invoke_result_data.success == False:
-                                invoke_result_data.success = False
-                                invoke_result_data.error_code = "error"
-                                invoke_result_data.error_message = "变更资产失败"
-                            else:
-                                invoke_result_data.data = {}
-                                for item in tao_pay_order_list:
+                            invoke_result_data.data = {}
+                            for item in tao_pay_order_list:       
+                                only_id =  f"sync_order_" + str(item.sub_pay_order_no)
+                                asset_invoke_result_data = asset_base_model.update_user_asset(app_id,act_id,module_id,user_id,user_info_dict["open_id"],user_info_dict["user_nick"],asset_type,item.buy_num,item.asset_object_id,1,"","","购买",only_id,handler_name,request_code,info_json={})
+                                if asset_invoke_result_data.success == False:
+                                    invoke_result_data.success = False
+                                    invoke_result_data.error_code = "error"
+                                    invoke_result_data.error_message = "变更资产失败"
+                                else:
                                     redis_init.lpush(pay_order_cache_key,item.sub_pay_order_no)
                                     redis_init.expire(pay_order_cache_key, 30 * 24 * 3600)
-                                invoke_result_data.data["asset_type"] = asset_type
-                                invoke_result_data.data["asset_object_id"] = asset_object_id
+                                    data = {}
+                                    data["asset_type"] = asset_type
+                                    data["asset_object_id"] = item.asset_object_id
+                                    data["buy_num"] = item.buy_num
+                                    invoke_result_data.data["asset_list"].append(data)
                                 invoke_result_data.data["buy_num"] = buy_num
                                 invoke_result_data.data["pay_price"] = pay_price
                                 invoke_result_data.data["pay_num"] = pay_num
+                    
                         else:
                             invoke_result_data.success = False
                             invoke_result_data.error_code = "error"
