@@ -2,13 +2,14 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-22 11:10:20
-@LastEditTime: 2021-09-02 17:32:22
+@LastEditTime: 2021-09-06 15:17:39
 @LastEditors: HuangJianYi
 @Description: 
 """
 
 from seven_cloudapp_frame.libs.customize.seven_helper import *
 from seven_cloudapp_frame.models.top_base_model import *
+from seven_cloudapp_frame.models.frame_base_model import FrameBaseModel
 from seven_cloudapp_frame.models.db_models.user.user_account_model import *
 from seven_cloudapp_frame.models.db_models.user.user_info_model import *
 from seven_cloudapp_frame.models.db_models.user.user_black_model import *
@@ -16,12 +17,13 @@ from seven_cloudapp_frame.models.db_models.act.act_module_model import *
 from seven_cloudapp_frame.models.db_models.act.act_prize_model import *
 from seven_cloudapp_frame.models.db_models.prize.prize_roster_model import *
 
-class UserBaseModel():
+class UserBaseModel(FrameBaseModel):
     """
     :description: 用户信息业务模型
     """
     def __init__(self, context):
         self.context = context
+        super(UserBaseModel,self).__init__(context)
 
     def _get_user_info_id_md5(self, act_id, user_id):
         """
@@ -154,7 +156,10 @@ class UserBaseModel():
         :last_editors: HuangJianYi
         """
         top_base_model = TopBaseModel(context=self.context)
-        return top_base_model.get_join_member_url(access_token,app_key,app_secret,is_log)
+        join_member_url = top_base_model.get_join_member_url(access_token,app_key,app_secret,is_log)
+        if join_member_url and "https:" not in join_member_url and "http:" not in join_member_url:
+            join_member_url = "https:" + join_member_url
+        return join_member_url
     
     def save_user_by_openid(self, app_id, act_id, open_id, user_nick, avatar, union_id=""):
         """
