@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-04-16 14:38:22
-@LastEditTime: 2021-08-26 16:41:16
+@LastEditTime: 2021-09-03 13:35:52
 @LastEditors: HuangJianYi
 :Description: 基础路由   业务方可以直接使用语句 handlers.extend(seven_cloudapp_frame.route.seven_cloudapp_frame_route()) 引入
 """
@@ -50,13 +50,14 @@ def seven_cloudapp_frame_route():
         (r"/client/weekly_sign", task.WeeklySignHandler),  #每周签到任务
         (r"/client/invite_new_user", task.InviteNewUserHandler),  #邀请新用户任务
         (r"/client/invite_join_member", task.InviteJoinMemberHandler),  #邀请加入会员任务
+        (r"/client/browse_site", task.BrowseSiteHandler),  #处理浏览网址相关任务 如：浏览店铺、浏览直播间、浏览会场/专题
         (r"/client/share_report", task.ShareReportHandler),  #分享统计上报
         (r"/client/collect_goods", task.CollectGoodsHandler),  #收藏商品任务
         (r"/client/browse_goods", task.BrowseGoodsHandler),  #浏览商品任务
         (r"/client/favor_store", task.FavorStoreHandler),  #关注店铺任务
         (r"/client/join_member", task.JoinMemberHandler),  #加入会员任务
 
-        #千牛端
+        #淘宝千牛端
         (r"/server/saas_custom", base_s.SaasCustomHandler),  #saas定制化信息获取
         (r"/server/login", user_s.LoginHandler),  #千牛端登录
         (r"/server/left_navigation", base_s.LeftNavigationHandler),  #左侧导航
